@@ -1,5 +1,5 @@
 import os
-from utils_types import CloudProvider
+from bodo_platform_utils.utils_types import CloudProvider
 
 WORKSPACE_UUID = os.environ.get("BODO_PLATFORM_WORKSPACE_UUID")
 REGION = os.environ.get("BODO_PLATFORM_WORKSPACE_REGION")
